agentle.agents.a2a.tasks.send\_task\_response
=============================================

.. automodule:: agentle.agents.a2a.tasks.send_task_response

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      JSONRPCError
      JSONRPCResponse
      SendTaskResponse
      Task
   